@@ -3,7 +3,7 @@ BEGIN {
   $MooseX::LazyRequire::AUTHORITY = 'cpan:FLORA';
 }
 BEGIN {
-  $MooseX::LazyRequire::VERSION = '0.06';
+  $MooseX::LazyRequire::VERSION = '0.07';
 }
 # ABSTRACT: Required attributes which fail only when trying to use them
 
@@ -13,12 +13,19 @@ use aliased 0.30 'MooseX::LazyRequire::Meta::Attribute::Trait::LazyRequire';
 use namespace::autoclean;
 
 
-Moose::Exporter->setup_import_methods(
+my %metaroles = (
     class_metaroles => {
         attribute => [LazyRequire],
     },
 );
 
+$metaroles{role_metaroles} = {
+    applied_attribute => [LazyRequire],
+    }
+    if $Moose::VERSION >= 1.9900;
+
+Moose::Exporter->setup_import_methods(%metaroles);
+
 1;
 
 
@@ -65,7 +72,7 @@ parameter or through a writer method.
 
 =head1 CAVEATS
 
-Apparently Moose roles don't have an attribute metaclass, so this module can't
+Prior to Moose 1.9900, roles didn't have an attribute metaclass, so this module can't
 easily apply its magic to attributes defined in roles. If you want to use
 C<lazy_required> in role attributes, you'll have to apply the attribute trait
 yourself:
@@ -76,15 +83,28 @@ yourself:
         lazy_required => 1,
     );
 
+With Moose 1.9900, you can use this module in roles just the same way you can
+in classes.
+
 =for Pod::Coverage init_meta
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Florian Ragwitz <rafl@debian.org>
 
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Florian Ragwitz.
+This software is copyright (c) 2011 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
